@@ -8,5 +8,5 @@ urlpatterns = patterns('large_data_admin.views',
     url(r'^check/(?P<app>[\w\-]+)/(?P<model>[\w\-]+)/(?P<pk>[\d]+)/(?P<field>[\w\-]+)/$', 'check_json'),
     url(r'^selected/(?P<app>[\w\-]+)/(?P<model>[\w\-]+)/(?P<pk>[\d]+)/(?P<field>[\w\-]+)/$', 'selected_json'),
 
-    url(r'^select/add/(?P<app>[\w\-]+)/(?P<model>[\w\-]+)/$', 'select_add_json'),
+    url(r'^select/add/(?P<model>[\w\-.]+)/$', 'select_add_json'),
 )
