@@ -3,7 +3,6 @@ from django.forms.widgets import Widget
 from django.template import loader
 from django.utils.safestring import mark_safe
 from django.conf import settings
-from django.db.models import get_model
 
 import random
 
@@ -34,20 +33,19 @@ class SelectWidget(Widget):
 
     def __init__(self, model, **kwargs):
         self.model = model
-        self.app_name = model.__module__.split(".")[0] # XXX
+        self.str_model = u"%s.%s"%(model.__module__, model.__name__)
         return super(self.__class__, self).__init__(**kwargs)
 
     def render(self, name, value, attrs=None, choices=()):
         if value:
-            Model = get_model(self.app_name, self.model.__name__)
+            Model = self.model
             text_value = Model.objects.get(pk=value).__unicode__()
         else:
             text_value = ""
         return mark_safe(loader.render_to_string("large_data_admin/select.html", {
             "STATIC_URL": settings.STATIC_URL,
             "selected": value,
-            "app": self.app_name,
-            "model": self.model.__name__,
+            "model": self.str_model,
             "field": name,
             "text_value": text_value,
             "prefix": str(random.randint(1000000000, 9999999999)),
